pub struct NodeInfo {
pub node_public_key: Vec<u8>,
pub network_ids: Vec<String>,
pub addresses: Vec<String>,
pub node_metadata: NodeMetadata,
pub version: i64,
}Expand description
Information about a node in the network
INTENTION: Represents a snapshot of a node’s presence and capabilities within one or more networks. This information is shared via discovery mechanisms.
Fields
node_public_key: Vec<u8>The node’s unique identifier
network_ids: Vec<String>The list of network IDs this node participates in and handles traffic for. A node can be part of multiple networks simultaneously.
addresses: Vec<String>The node’s network addressess (e.g., “IP:PORT”) - ordered by preference
node_metadata: NodeMetadataNode services representing the services provided by this node
version: i64incremental version counter that change everytime the node changes (new services added, new event subscriptions, etc) when that happens a new version is published to known peers.. and that is how peers know if they need to update their own version of it